@@ -16,7 +16,7 @@ class EcoNameTranslator:
         self.result = {}
         self.failed = {}
     
-    def translate(self,uncheckedNames):
+    def translate(self,uncheckedNames,includeCommon=True):
         print("Beginnging name reformatting")
         for item in uncheckedNames:
             self.index[item] = [cleanSingleSpeciesString(item),'']
@@ -26,28 +26,41 @@ class EcoNameTranslator:
         print("Expanding higher level taxonomic names")
         self.mapKnownTaxaLevelToSpecies()
         print("Trying common name translation...(this may take a while)")
-        self.tryCommonNameOnErrorCases()
+        if includeCommon: self.tryCommonNameOnErrorCases()
         self.ensureUniqueInIndex()
         return self.index
     
     def tagInputWithTaxaLevel(self):
-        names = list(map(lambda x: self.index[x][0], self.index.keys()))
-        taxonomyAPIResuls, excepted = taxonomyAPI(names)
-        self.writeApiResultsToIndex(taxonomyAPIResuls)
+        try:
+            names = list(map(lambda x: self.index[x][0], self.index.keys()))
+            taxonomyAPIResuls, excepted = taxonomyAPI(names)
+            self.writeApiResultsToIndex(taxonomyAPIResuls)
+        except Exception as e:
+            print("Caught fatal exception in taxonomic indexer")
+            print(str(e))
+
     
     def mapKnownTaxaLevelToSpecies(self):
-        names = list(map(lambda x: self.index[x][0], self.index.keys()))
-        taxaTuples = list(map(lambda x: self.index[x][1], self.index.keys()))
-        originalNamesWthTaxa = list(zip(names,taxaTuples))
-        speciesNamesOnly = higherLevelAPI(originalNamesWthTaxa)
-        self.writeApiResultsToIndex(speciesNamesOnly)
+        try:
+            names = list(map(lambda x: self.index[x][0], self.index.keys()))
+            taxaTuples = list(map(lambda x: self.index[x][1], self.index.keys()))
+            originalNamesWthTaxa = list(zip(names,taxaTuples))
+            speciesNamesOnly = higherLevelAPI(originalNamesWthTaxa)
+            self.writeApiResultsToIndex(speciesNamesOnly)
+        except Exception as e:
+            print("Caught fatal exception in taxonomic level resolver")
+            print(str(e))
     
     def tryCommonNameOnErrorCases(self):
-        names = list(map(lambda x: self.index[x][0], self.index.keys()))
-        currentSpeciesResults = list(map(lambda x: self.index[x][1], self.index.keys()))
-        bestEffortOfSpecies = list(zip(names,currentSpeciesResults))
-        speciesNamesOnly = commonNameAPI(bestEffortOfSpecies)
-        self.writeApiResultsToIndex(speciesNamesOnly)
+        try:
+            names = list(map(lambda x: self.index[x][0], self.index.keys()))
+            currentSpeciesResults = list(map(lambda x: self.index[x][1], self.index.keys()))
+            bestEffortOfSpecies = list(zip(names,currentSpeciesResults))
+            speciesNamesOnly = commonNameAPI(bestEffortOfSpecies)
+            self.writeApiResultsToIndex(speciesNamesOnly)
+        except Exception as e:
+            print("Caught fatal exception in common name resolver")
+            print(str(e))
     
     def writeApiResultsToIndex(self,taxonomyAPIResuls):
         taxaAPIDict = {}
